==> ejc-accplat-impl-3.0.0-20240102.014812-61-sources.jar: com/ejianc/business/accplat/originvoucher/bean/OriginVoucherEntryEntity.java <==
package com.ejianc.business.accplat.originvoucher.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 原始凭证分录
 *
 * @author generator
 *
 */
@TableName("ejc_accplat_origin_voucher_entry")
public class OriginVoucherEntryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "origin_voucher_id")
    private Long originVoucherId; // 原始凭证ID
    @TableField(value = "entry_description")
    private String entryDescription; // 分录摘要
    @TableField(value = "subject_id")
    private Long subjectId; // 科目ID
    @TableField(value = "subject_code")
    private String subjectCode; // 科目编码
    @TableField(value = "subject_name")
    private String subjectName; // 科目名称
    @TableField(value = "auxiliary_info")
    private String auxiliaryInfo; // 辅助核算项展示信息
    @TableField(value = "debit_original_mny")
    private BigDecimal debitOriginalMny; // 借方原币金额
    @TableField(value = "crebit_original_mny")
    private BigDecimal crebitOriginalMny; // 贷方原币金额
    @TableField(value = "direction_flag")
    private String directionFlag; // 借贷方向debit借crebit贷
    @TableField(value = "rate_type")
    private String rateType; // 汇率类型
    @TableField(value = "currency_code")
    private String currencyCode; // 币别


    public Long getOriginVoucherId() {
        return originVoucherId;
    }

    public void setOriginVoucherId(Long originVoucherId) {
        this.originVoucherId = originVoucherId;
    }

    public String getEntryDescription() {
        return entryDescription;
    }

    public void setEntryDescription(String entryDescription) {
        this.entryDescription = entryDescription;
    }

    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public String getAuxiliaryInfo() {
        return auxiliaryInfo;
    }

    public void setAuxiliaryInfo(String auxiliaryInfo) {
        this.auxiliaryInfo = auxiliaryInfo;
    }

    public BigDecimal getDebitOriginalMny() {
        return debitOriginalMny;
    }

    public void setDebitOriginalMny(BigDecimal debitOriginalMny) {
        this.debitOriginalMny = debitOriginalMny;
    }

    public BigDecimal getCrebitOriginalMny() {
        return crebitOriginalMny;
    }

    public void setCrebitOriginalMny(BigDecimal crebitOriginalMny) {
        this.crebitOriginalMny = crebitOriginalMny;
    }

    public String getDirectionFlag() {
        return directionFlag;
    }

    public void setDirectionFlag(String directionFlag) {
        this.directionFlag = directionFlag;
    }

    public String getRateType() {
        return rateType;
    }

    public void setRateType(String rateType) {
        this.rateType = rateType;
    }

    public String getCurrencyCode() {
        return currencyCode;
    }

    public void setCurrencyCode(String currencyCode) {
        this.currencyCode = currencyCode;
    }

}

==> ejc-accplat-impl-3.0.0-20240525.083653-189-sources.jar: com/ejianc/business/accplat/originvoucher/bean/OriginVoucherEntryEntity.java <==
package com.ejianc.business.accplat.originvoucher.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 原始凭证分录
 *
 * @author generator
 *
 */
@TableName("ejc_accplat_origin_voucher_entry")
public class OriginVoucherEntryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "origin_voucher_id")
    private Long originVoucherId; // 原始凭证ID
    @TableField(value = "entry_description")
    private String entryDescription; // 分录摘要
    @TableField(value = "subject_id")
    private Long subjectId; // 科目ID
    @TableField(value = "subject_code")
    private String subjectCode; // 科目编码
    @TableField(value = "subject_name")
    private String subjectName; // 科目名称
    @TableField(value="auxiliary_ids")
    private String auxiliaryIds; // 辅助核算项ids
    @TableField(value = "auxiliary_info")
    private String auxiliaryInfo; // 辅助核算项展示信息
    @TableField(value = "debit_original_mny")
    private BigDecimal debitOriginalMny; // 借方原币金额
    @TableField(value = "credit_original_mny")
    private BigDecimal creditOriginalMny; // 贷方原币金额
    @TableField(value = "direction_flag")
    private String directionFlag; // 借贷方向debit借credit贷
    @TableField(value = "rate_type")
    private String rateType; // 汇率类型
    @TableField(value = "currency_code")
    private String currencyCode; // 币别

    public String getAuxiliaryIds() {
        return auxiliaryIds;
    }

    public void setAuxiliaryIds(String auxiliaryIds) {
        this.auxiliaryIds = auxiliaryIds;
    }

    public Long getOriginVoucherId() {
        return originVoucherId;
    }

    public void setOriginVoucherId(Long originVoucherId) {
        this.originVoucherId = originVoucherId;
    }

    public String getEntryDescription() {
        return entryDescription;
    }

    public void setEntryDescription(String entryDescription) {
        this.entryDescription = entryDescription;
    }

    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public String getAuxiliaryInfo() {
        return auxiliaryInfo;
    }

    public void setAuxiliaryInfo(String auxiliaryInfo) {
        this.auxiliaryInfo = auxiliaryInfo;
    }

    public BigDecimal getDebitOriginalMny() {
        return debitOriginalMny;
    }

    public void setDebitOriginalMny(BigDecimal debitOriginalMny) {
        this.debitOriginalMny = debitOriginalMny;
    }

    public BigDecimal getCreditOriginalMny() {
        return creditOriginalMny;
    }

    public void setCreditOriginalMny(BigDecimal creditOriginalMny) {
        this.creditOriginalMny = creditOriginalMny;
    }

    public String getDirectionFlag() {
        return directionFlag;
    }

    public void setDirectionFlag(String directionFlag) {
        this.directionFlag = directionFlag;
    }

    public String getRateType() {
        return rateType;
    }

    public void setRateType(String rateType) {
        this.rateType = rateType;
    }

    public String getCurrencyCode() {
        return currencyCode;
    }

    public void setCurrencyCode(String currencyCode) {
        this.currencyCode = currencyCode;
    }

}
